==> ejc-settle-api-3.0.0-20240621.053006-62-sources.jar: com/ejianc/business/settle/bean/SettlementCenterBudgetMeasureVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 设备及安装工程
 *
 * @author generator
 */
public class SettlementCenterBudgetMeasureVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetMeasureId; // budget_measure主键
    private Long budgetId; // 预算书主键
    private String detailIndex; // 序号
    private Long parentId; // 父ID
    private String measureCode; // 编码
    private String measureName; // 名称
    private String measureFeature; // 特征
    private String measureUnit; // 单位
    private BigDecimal measureNum; // 承包合同工程量
    private BigDecimal quoteMeasureNum; // 对甲结算工程量
    private BigDecimal settlementCenterMeasureNum; // 统计工程量
    private BigDecimal measureTaxRate; // 税率
    private BigDecimal measurePrice; // 综合单价(无税)
    private BigDecimal measureTaxPrice; // 综合单价(含税)
    private BigDecimal measureMny; // 承包合同合价(无税)
    private BigDecimal measureTaxMny; // 承包合同合价(含税)
    private BigDecimal measureTax; // 税额
    private BigDecimal quoteMeasureMny; // 对甲结算产值(无税)
    private BigDecimal quoteMeasureTaxMny; // 对甲结产值(含税)
    private BigDecimal quoteMeasureTax; // 对甲结算产值税额
    private BigDecimal settlementCenterMeasureMny; // 统计产值(无税)
    private BigDecimal settlementCenterMeasureTaxMny; // 统计产值(含税)
    private BigDecimal settlementCenterMeasureTax; // 统计产值税额
    private String measureMemo; // 备注
    private Integer leafFlag; // 是否末级
    private Long measureSubjectId; // 成本科目id
    private String measureSubjectName; // 成本科目名称
    private BigDecimal measurePriceEquipment; // 设备购置费(单价)
    private BigDecimal measurePriceInstall; // 安装费单价(单价)
    private BigDecimal measurePriceMaterial; // 甲供装置性材料费(单价)
    private BigDecimal measurePriceSum; // 小计(单价)
    private BigDecimal measureMnyEquipment; // 设备购置费(合价)
    private BigDecimal measureMnyInstall; // 安装费单价(合价)
    private BigDecimal measureMnyMaterial; // 甲供装置性材料费(合价)
    private BigDecimal measureMnySum; // 小计(合价)
    private Long dcDrwgrpInfo; // settlement_center_dc_drwgrp_info主键 0 代表 为预算书缓存
    private String errorMessage;//错误信息集合
    private Integer rowIndex;

    private BigDecimal settlementCenterMeasureNumTotal; // 累计统计工程量
    private BigDecimal settlementCenterMeasureMnyTotal; // 累计统计产值(无税)
    private BigDecimal settlementCenterMeasureTaxMnyTotal; // 累计统计产值(含税)
    private BigDecimal settlementCenterMeasureTaxTotal; // 累计统计产值税额

    private List<SettlementCenterBudgetMeasureVO> children;


    public Long getDcDrwgrpInfo() {
        return dcDrwgrpInfo;
    }

    public void setDcDrwgrpInfo(Long dcDrwgrpInfo) {
        this.dcDrwgrpInfo = dcDrwgrpInfo;
    }

    public Long getBudgetMeasureId() {
        return budgetMeasureId;
    }

    public void setBudgetMeasureId(Long budgetMeasureId) {
        this.budgetMeasureId = budgetMeasureId;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getMeasureCode() {
        return measureCode;
    }

    public void setMeasureCode(String measureCode) {
        this.measureCode = measureCode;
    }

    public String getMeasureName() {
        return measureName;
    }

    public void setMeasureName(String measureName) {
        this.measureName = measureName;
    }

    public String getMeasureFeature() {
        return measureFeature;
    }

    public void setMeasureFeature(String measureFeature) {
        this.measureFeature = measureFeature;
    }

    public String getMeasureUnit() {
        return measureUnit;
    }

    public void setMeasureUnit(String measureUnit) {
        this.measureUnit = measureUnit;
    }

    public BigDecimal getMeasureNum() {
        return measureNum;
    }

    public void setMeasureNum(BigDecimal measureNum) {
        this.measureNum = measureNum;
    }

    public BigDecimal getQuoteMeasureNum() {
        return quoteMeasureNum;
    }

    public void setQuoteMeasureNum(BigDecimal quoteMeasureNum) {
        this.quoteMeasureNum = quoteMeasureNum;
    }

    public BigDecimal getSettlementCenterMeasureNum() {
        return settlementCenterMeasureNum;
    }

    public void setSettlementCenterMeasureNum(BigDecimal settlementCenterMeasureNum) {
        this.settlementCenterMeasureNum = settlementCenterMeasureNum;
    }

    public BigDecimal getMeasureTaxRate() {
        return measureTaxRate;
    }

    public void setMeasureTaxRate(BigDecimal measureTaxRate) {
        this.measureTaxRate = measureTaxRate;
    }

    public BigDecimal getMeasurePrice() {
        return measurePrice;
    }

    public void setMeasurePrice(BigDecimal measurePrice) {
        this.measurePrice = measurePrice;
    }

    public BigDecimal getMeasureTaxPrice() {
        return measureTaxPrice;
    }

    public void setMeasureTaxPrice(BigDecimal measureTaxPrice) {
        this.measureTaxPrice = measureTaxPrice;
    }

    public BigDecimal getMeasureMny() {
        return measureMny;
    }

    public void setMeasureMny(BigDecimal measureMny) {
        this.measureMny = measureMny;
    }

    public BigDecimal getMeasureTaxMny() {
        return measureTaxMny;
    }

    public void setMeasureTaxMny(BigDecimal measureTaxMny) {
        this.measureTaxMny = measureTaxMny;
    }

    public BigDecimal getMeasureTax() {
        return measureTax;
    }

    public void setMeasureTax(BigDecimal measureTax) {
        this.measureTax = measureTax;
    }

    public BigDecimal getQuoteMeasureMny() {
        return quoteMeasureMny;
    }

    public void setQuoteMeasureMny(BigDecimal quoteMeasureMny) {
        this.quoteMeasureMny = quoteMeasureMny;
    }

    public BigDecimal getQuoteMeasureTaxMny() {
        return quoteMeasureTaxMny;
    }

    public void setQuoteMeasureTaxMny(BigDecimal quoteMeasureTaxMny) {
        this.quoteMeasureTaxMny = quoteMeasureTaxMny;
    }

    public BigDecimal getQuoteMeasureTax() {
        return quoteMeasureTax;
    }

    public void setQuoteMeasureTax(BigDecimal quoteMeasureTax) {
        this.quoteMeasureTax = quoteMeasureTax;
    }

    public BigDecimal getSettlementCenterMeasureMny() {
        return settlementCenterMeasureMny;
    }

    public void setSettlementCenterMeasureMny(BigDecimal settlementCenterMeasureMny) {
        this.settlementCenterMeasureMny = settlementCenterMeasureMny;
    }

    public BigDecimal getSettlementCenterMeasureTaxMny() {
        return settlementCenterMeasureTaxMny;
    }

    public void setSettlementCenterMeasureTaxMny(BigDecimal settlementCenterMeasureTaxMny) {
        this.settlementCenterMeasureTaxMny = settlementCenterMeasureTaxMny;
    }

    public BigDecimal getSettlementCenterMeasureTax() {
        return settlementCenterMeasureTax;
    }

    public void setSettlementCenterMeasureTax(BigDecimal settlementCenterMeasureTax) {
        this.settlementCenterMeasureTax = settlementCenterMeasureTax;
    }

    public String getMeasureMemo() {
        return measureMemo;
    }

    public void setMeasureMemo(String measureMemo) {
        this.measureMemo = measureMemo;
    }

    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }

    public Long getMeasureSubjectId() {
        return measureSubjectId;
    }

    public void setMeasureSubjectId(Long measureSubjectId) {
        this.measureSubjectId = measureSubjectId;
    }

    public String getMeasureSubjectName() {
        return measureSubjectName;
    }

    public void setMeasureSubjectName(String measureSubjectName) {
        this.measureSubjectName = measureSubjectName;
    }

    public BigDecimal getMeasurePriceEquipment() {
        return measurePriceEquipment;
    }

    public void setMeasurePriceEquipment(BigDecimal measurePriceEquipment) {
        this.measurePriceEquipment = measurePriceEquipment;
    }

    public BigDecimal getMeasurePriceInstall() {
        return measurePriceInstall;
    }

    public void setMeasurePriceInstall(BigDecimal measurePriceInstall) {
        this.measurePriceInstall = measurePriceInstall;
    }

    public BigDecimal getMeasurePriceMaterial() {
        return measurePriceMaterial;
    }

    public void setMeasurePriceMaterial(BigDecimal measurePriceMaterial) {
        this.measurePriceMaterial = measurePriceMaterial;
    }

    public BigDecimal getMeasurePriceSum() {
        return measurePriceSum;
    }

    public void setMeasurePriceSum(BigDecimal measurePriceSum) {
        this.measurePriceSum = measurePriceSum;
    }

    public BigDecimal getMeasureMnyEquipment() {
        return measureMnyEquipment;
    }

    public void setMeasureMnyEquipment(BigDecimal measureMnyEquipment) {
        this.measureMnyEquipment = measureMnyEquipment;
    }

    public BigDecimal getMeasureMnyInstall() {
        return measureMnyInstall;
    }

    public void setMeasureMnyInstall(BigDecimal measureMnyInstall) {
        this.measureMnyInstall = measureMnyInstall;
    }

    public BigDecimal getMeasureMnyMaterial() {
        return measureMnyMaterial;
    }

    public void setMeasureMnyMaterial(BigDecimal measureMnyMaterial) {
        this.measureMnyMaterial = measureMnyMaterial;
    }

    public BigDecimal getMeasureMnySum() {
        return measureMnySum;
    }

    public void setMeasureMnySum(BigDecimal measureMnySum) {
        this.measureMnySum = measureMnySum;
    }

    public List<SettlementCenterBudgetMeasureVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementCenterBudgetMeasureVO> children) {
        this.children = children;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public Integer getRowIndex() {
        return rowIndex;
    }

    public void setRowIndex(Integer rowIndex) {
        this.rowIndex = rowIndex;
    }

    public BigDecimal getSettlementCenterMeasureNumTotal() {
        return settlementCenterMeasureNumTotal;
    }

    public void setSettlementCenterMeasureNumTotal(BigDecimal settlementCenterMeasureNumTotal) {
        this.settlementCenterMeasureNumTotal = settlementCenterMeasureNumTotal;
    }

    public BigDecimal getSettlementCenterMeasureMnyTotal() {
        return settlementCenterMeasureMnyTotal;
    }

    public void setSettlementCenterMeasureMnyTotal(BigDecimal settlementCenterMeasureMnyTotal) {
        this.settlementCenterMeasureMnyTotal = settlementCenterMeasureMnyTotal;
    }

    public BigDecimal getSettlementCenterMeasureTaxMnyTotal() {
        return settlementCenterMeasureTaxMnyTotal;
    }

    public void setSettlementCenterMeasureTaxMnyTotal(BigDecimal settlementCenterMeasureTaxMnyTotal) {
        this.settlementCenterMeasureTaxMnyTotal = settlementCenterMeasureTaxMnyTotal;
    }

    public BigDecimal getSettlementCenterMeasureTaxTotal() {
        return settlementCenterMeasureTaxTotal;
    }

    public void setSettlementCenterMeasureTaxTotal(BigDecimal settlementCenterMeasureTaxTotal) {
        this.settlementCenterMeasureTaxTotal = settlementCenterMeasureTaxTotal;
    }
}

==> ejc-settle-api-3.0.0-20250826.072832-174-sources.jar: com/ejianc/business/settle/bean/SettlementCenterBudgetMeasureVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 设备及安装工程
 *
 * @author generator
 */
public class SettlementCenterBudgetMeasureVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetMeasureId; // budget_measure主键
    private Long budgetId; // 预算书主键
    private String detailIndex; // 序号
    private Long parentId; // 父ID
    private String measureCode; // 编码
    private String measureName; // 名称
    private String measureFeature; // 特征
    private String measureUnit; // 单位
    private BigDecimal measureNum; // 承包合同工程量
    private BigDecimal quoteMeasureNum; // 对甲结算工程量
    private BigDecimal settlementCenterMeasureNum; // 统计工程量
    private BigDecimal measureTaxRate; // 税率
    private BigDecimal measurePrice; // 综合单价(无税)
    private BigDecimal measureTaxPrice; // 综合单价(含税)
    private BigDecimal measureMny; // 承包合同合价(无税)
    private BigDecimal measureTaxMny; // 承包合同合价(含税)
    private BigDecimal measureTax; // 税额
    private BigDecimal quoteMeasureMny; // 对甲结算产值(无税)
    private BigDecimal quoteMeasureTaxMny; // 对甲结产值(含税)
    private BigDecimal quoteMeasureTax; // 对甲结算产值税额
    private BigDecimal settlementCenterMeasureMny; // 统计产值(无税)
    private BigDecimal settlementCenterMeasureTaxMny; // 统计产值(含税)
    private BigDecimal settlementCenterMeasureTax; // 统计产值税额
    private String measureMemo; // 备注
    private Integer leafFlag; // 是否末级
    private Long measureSubjectId; // 成本科目id
    private String measureSubjectName; // 成本科目名称
    private BigDecimal measurePriceEquipment; // 设备购置费(单价)
    private BigDecimal measurePriceInstall; // 安装费单价(单价)
    private BigDecimal measurePriceMaterial; // 甲供装置性材料费(单价)
    private BigDecimal measurePriceSum; // 小计(单价)
    private BigDecimal measureMnyEquipment; // 设备购置费(合价)
    private BigDecimal measureMnyInstall; // 安装费单价(合价)
    private BigDecimal measureMnyMaterial; // 甲供装置性材料费(合价)
    private BigDecimal measureMnySum; // 小计(合价)
    private Long dcDrwgrpInfo; // settlement_center_dc_drwgrp_info主键 0 代表 为预算书缓存
    private String errorMessage;//错误信息集合
    private Integer rowIndex;

    private BigDecimal settlementCenterMeasureNumTotal; // 累计统计工程量
    private BigDecimal settlementCenterMeasureMnyTotal; // 累计统计产值(无税)
    private BigDecimal settlementCenterMeasureTaxMnyTotal; // 累计统计产值(含税)
    private BigDecimal settlementCenterMeasureTaxTotal; // 累计统计产值税额

    private List<SettlementCenterBudgetMeasureVO> children;


    public Long getDcDrwgrpInfo() {
        return dcDrwgrpInfo;
    }

    public void setDcDrwgrpInfo(Long dcDrwgrpInfo) {
        this.dcDrwgrpInfo = dcDrwgrpInfo;
    }

    public Long getBudgetMeasureId() {
        return budgetMeasureId;
    }

    public void setBudgetMeasureId(Long budgetMeasureId) {
        this.budgetMeasureId = budgetMeasureId;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getMeasureCode() {
        return measureCode;
    }

    public void setMeasureCode(String measureCode) {
        this.measureCode = measureCode;
    }

    public String getMeasureName() {
        return measureName;
    }

    public void setMeasureName(String measureName) {
        this.measureName = measureName;
    }

    public String getMeasureFeature() {
        return measureFeature;
    }

    public void setMeasureFeature(String measureFeature) {
        this.measureFeature = measureFeature;
    }

    public String getMeasureUnit() {
        return measureUnit;
    }

    public void setMeasureUnit(String measureUnit) {
        this.measureUnit = measureUnit;
    }

    public BigDecimal getMeasureNum() {
        return measureNum;
    }

    public void setMeasureNum(BigDecimal measureNum) {
        this.measureNum = measureNum;
    }

    public BigDecimal getQuoteMeasureNum() {
        return quoteMeasureNum;
    }

    public void setQuoteMeasureNum(BigDecimal quoteMeasureNum) {
        this.quoteMeasureNum = quoteMeasureNum;
    }

    public BigDecimal getSettlementCenterMeasureNum() {
        return settlementCenterMeasureNum;
    }

    public void setSettlementCenterMeasureNum(BigDecimal settlementCenterMeasureNum) {
        this.settlementCenterMeasureNum = settlementCenterMeasureNum;
    }

    public BigDecimal getMeasureTaxRate() {
        return measureTaxRate;
    }

    public void setMeasureTaxRate(BigDecimal measureTaxRate) {
        this.measureTaxRate = measureTaxRate;
    }

    public BigDecimal getMeasurePrice() {
        return measurePrice;
    }

    public void setMeasurePrice(BigDecimal measurePrice) {
        this.measurePrice = measurePrice;
    }

    public BigDecimal getMeasureTaxPrice() {
        return measureTaxPrice;
    }

    public void setMeasureTaxPrice(BigDecimal measureTaxPrice) {
        this.measureTaxPrice = measureTaxPrice;
    }

    public BigDecimal getMeasureMny() {
        return measureMny;
    }

    public void setMeasureMny(BigDecimal measureMny) {
        this.measureMny = measureMny;
    }

    public BigDecimal getMeasureTaxMny() {
        return measureTaxMny;
    }

    public void setMeasureTaxMny(BigDecimal measureTaxMny) {
        this.measureTaxMny = measureTaxMny;
    }

    public BigDecimal getMeasureTax() {
        return measureTax;
    }

    public void setMeasureTax(BigDecimal measureTax) {
        this.measureTax = measureTax;
    }

    public BigDecimal getQuoteMeasureMny() {
        return quoteMeasureMny;
    }

    public void setQuoteMeasureMny(BigDecimal quoteMeasureMny) {
        this.quoteMeasureMny = quoteMeasureMny;
    }

    public BigDecimal getQuoteMeasureTaxMny() {
        return quoteMeasureTaxMny;
    }

    public void setQuoteMeasureTaxMny(BigDecimal quoteMeasureTaxMny) {
        this.quoteMeasureTaxMny = quoteMeasureTaxMny;
    }

    public BigDecimal getQuoteMeasureTax() {
        return quoteMeasureTax;
    }

    public void setQuoteMeasureTax(BigDecimal quoteMeasureTax) {
        this.quoteMeasureTax = quoteMeasureTax;
    }

    public BigDecimal getSettlementCenterMeasureMny() {
        return settlementCenterMeasureMny;
    }

    public void setSettlementCenterMeasureMny(BigDecimal settlementCenterMeasureMny) {
        this.settlementCenterMeasureMny = settlementCenterMeasureMny;
    }

    public BigDecimal getSettlementCenterMeasureTaxMny() {
        return settlementCenterMeasureTaxMny;
    }

    public void setSettlementCenterMeasureTaxMny(BigDecimal settlementCenterMeasureTaxMny) {
        this.settlementCenterMeasureTaxMny = settlementCenterMeasureTaxMny;
    }

    public BigDecimal getSettlementCenterMeasureTax() {
        return settlementCenterMeasureTax;
    }

    public void setSettlementCenterMeasureTax(BigDecimal settlementCenterMeasureTax) {
        this.settlementCenterMeasureTax = settlementCenterMeasureTax;
    }

    public String getMeasureMemo() {
        return measureMemo;
    }

    public void setMeasureMemo(String measureMemo) {
        this.measureMemo = measureMemo;
    }

    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    @ReferSerialTransfer(referCode = "subject-project-org-ref")
    public Long getMeasureSubjectId() {
        return measureSubjectId;
    }
    @ReferDeserialTransfer
    public void setMeasureSubjectId(Long measureSubjectId) {
        this.measureSubjectId = measureSubjectId;
    }

    public String getMeasureSubjectName() {
        return measureSubjectName;
    }

    public void setMeasureSubjectName(String measureSubjectName) {
        this.measureSubjectName = measureSubjectName;
    }

    public BigDecimal getMeasurePriceEquipment() {
        return measurePriceEquipment;
    }

    public void setMeasurePriceEquipment(BigDecimal measurePriceEquipment) {
        this.measurePriceEquipment = measurePriceEquipment;
    }

    public BigDecimal getMeasurePriceInstall() {
        return measurePriceInstall;
    }

    public void setMeasurePriceInstall(BigDecimal measurePriceInstall) {
        this.measurePriceInstall = measurePriceInstall;
    }

    public BigDecimal getMeasurePriceMaterial() {
        return measurePriceMaterial;
    }

    public void setMeasurePriceMaterial(BigDecimal measurePriceMaterial) {
        this.measurePriceMaterial = measurePriceMaterial;
    }

    public BigDecimal getMeasurePriceSum() {
        return measurePriceSum;
    }

    public void setMeasurePriceSum(BigDecimal measurePriceSum) {
        this.measurePriceSum = measurePriceSum;
    }

    public BigDecimal getMeasureMnyEquipment() {
        return measureMnyEquipment;
    }

    public void setMeasureMnyEquipment(BigDecimal measureMnyEquipment) {
        this.measureMnyEquipment = measureMnyEquipment;
    }

    public BigDecimal getMeasureMnyInstall() {
        return measureMnyInstall;
    }

    public void setMeasureMnyInstall(BigDecimal measureMnyInstall) {
        this.measureMnyInstall = measureMnyInstall;
    }

    public BigDecimal getMeasureMnyMaterial() {
        return measureMnyMaterial;
    }

    public void setMeasureMnyMaterial(BigDecimal measureMnyMaterial) {
        this.measureMnyMaterial = measureMnyMaterial;
    }

    public BigDecimal getMeasureMnySum() {
        return measureMnySum;
    }

    public void setMeasureMnySum(BigDecimal measureMnySum) {
        this.measureMnySum = measureMnySum;
    }

    public List<SettlementCenterBudgetMeasureVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementCenterBudgetMeasureVO> children) {
        this.children = children;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public Integer getRowIndex() {
        return rowIndex;
    }

    public void setRowIndex(Integer rowIndex) {
        this.rowIndex = rowIndex;
    }

    public BigDecimal getSettlementCenterMeasureNumTotal() {
        return settlementCenterMeasureNumTotal;
    }

    public void setSettlementCenterMeasureNumTotal(BigDecimal settlementCenterMeasureNumTotal) {
        this.settlementCenterMeasureNumTotal = settlementCenterMeasureNumTotal;
    }

    public BigDecimal getSettlementCenterMeasureMnyTotal() {
        return settlementCenterMeasureMnyTotal;
    }

    public void setSettlementCenterMeasureMnyTotal(BigDecimal settlementCenterMeasureMnyTotal) {
        this.settlementCenterMeasureMnyTotal = settlementCenterMeasureMnyTotal;
    }

    public BigDecimal getSettlementCenterMeasureTaxMnyTotal() {
        return settlementCenterMeasureTaxMnyTotal;
    }

    public void setSettlementCenterMeasureTaxMnyTotal(BigDecimal settlementCenterMeasureTaxMnyTotal) {
        this.settlementCenterMeasureTaxMnyTotal = settlementCenterMeasureTaxMnyTotal;
    }

    public BigDecimal getSettlementCenterMeasureTaxTotal() {
        return settlementCenterMeasureTaxTotal;
    }

    public void setSettlementCenterMeasureTaxTotal(BigDecimal settlementCenterMeasureTaxTotal) {
        this.settlementCenterMeasureTaxTotal = settlementCenterMeasureTaxTotal;
    }
}
